##  Procedure
  1. Create a user with the Data Link Admin permission and save keyAccess and keySecret.
  2. Add permissions to the branch/trunk you want to import the SAP LeanIX data to.
  3. Find out loginUrl, domain, environmentName.
  4. Uploader Service URL (ulsUrl) for the region where your Apptio environment belongs. See below for more details.
  5. Download URLs for tables can be generated in Apptio TBM for each desired table
